@@ -248,7 +248,8 @@ validate.litter <- function(x, type_names, logger = create_logger(level = "INFO"
     }
     
     # return validated data
-    x
+    x %>%
+        mutate(.RECORD_ID = RECORD_ID)
 }
 
 
@@ -262,7 +263,6 @@ validate.litter <- function(x, type_names, logger = create_logger(level = "INFO"
 #' @importFrom readr parse_date
 #' @importFrom rlang are_na
 #' @importFrom stringr str_glue
-#' @importFrom stringr str_glue
 validate.litter_types <- function(x, logger = create_logger(level = "INFO"), ...) {
 
     logger$info("Validating type file")
